@@ -86,6 +86,9 @@ mod no_conversion {
             case(vec!["3.5", "4.5", "4,5"], "^(?:3\\.5|4[,.]5)$"),
             case(vec!["\u{b}"], "^\\v$"), // U+000B Line Tabulation
             case(vec!["\\u{b}"], "^\\\\u\\{b\\}$"),
+            case(vec!["\u{c}"], "^\\f$"), // U+000C Form Feed
+            case(vec!["\\u{c}"], "^\\\\u\\{c\\}$"),
+            case(vec!["\u{200b}"], "^​$"),
             case(vec!["I ♥ cake"], "^I ♥ cake$"),
             case(vec!["I \u{2665} cake"], "^I ♥ cake$"),
             case(vec!["I \\u{2665} cake"], "^I \\\\u\\{2665\\} cake$"),
@@ -186,6 +189,13 @@ mod no_conversion {
                   \ \ \ 
                 $"#
             )),
+            case(vec!["\u{200b}"], indoc!(
+                r#"
+                (?x)
+                ^
+                  ​
+                $"#
+            )),
             case(vec!["a", "b", "c"], indoc!(
                 r#"
                 (?x)
@@ -2096,7 +2106,7 @@ mod anchor_conversion {
             case(vec!["bab", "b", "cb", "bba"], "(?:b(?:ba|ab)?|cb)"),
             case(vec!["a", "aba", "baaa", "aaab"], "(?:baaa|a(?:aab|ba)?)"),
             case(vec!["a", "abab", "bbb", "aaac"], "(?:a(?:bab|aac)?|bbb)"),
-            case(vec!["aaacaac", "aac"], "(?:aaacaac|aac)"), // "aa(?:acaa)?c" would not match "aaacaac"
+            case(vec!["aaacaac", "aac"], "aa(?:acaa)?c"),
             case(vec!["My ♥♥♥ and 💩💩 is yours."], "My ♥♥♥ and 💩💩 is yours\\."),
             case(
                 // https://github.com/pemistahl/grex/issues/31
@@ -2158,11 +2168,11 @@ mod anchor_conversion {
             case(vec!["aaacaac", "aac"], indoc!(
                 r#"
                 (?x)
+                  aa
                   (?:
-                    aaacaac
-                    |
-                    aac
-                  )"#
+                    acaa
+                  )?
+                  c"#
             )),
             case(vec!["My ♥♥♥ and 💩💩 is yours."], indoc!(
                 r#"
